===
GCS
===

GCS is a Django library that provides a storage backend for Google Cloud Storage.
It's currently built with dependency on GAE library and use within GAE, but that
could be abstracted out.

Installation
------------

.. code-block:: sh

    $ pip install fh-django-gcs

Running tests
-------------

TODO

Usage
-----

TODO
